@@ -93,7 +93,7 @@ class Algo:
     def save_algo(self):
         try:
             if self.test_mode: raise Exception("Test mode on. No Saving.")
-            fs = open(self.mem_file ,"wb")
+            fs = open(self.mem_file ,"w+b")
             to_save = self.Memory(self.tickers, self.wallet, self.positions)
             pickle.dump(to_save,fs)
             fs.close()
@@ -103,19 +103,19 @@ class Algo:
 
     def load_algo(self):
         if "test" in self.GUID.lower():
-            self.log.warn("Running test algo. Ignoring .pkl save...")
+            self.log.warn("Running test algo instance. Ignoring .pkl save...")
             return
         try:
             fs = open(self.mem_file ,"rb")
             from_save = pickle.load(fs)
-            if self.tickers != from_save.ticker:
+            if self.tickers != from_save.tickers:
                 raise Exception("Incompatable ticker found in mem. Resetting...")
             self.wallet = from_save.wallet
             self.positions = from_save.positions
             self.log.info("Found Memory||     wallet:{}".format(self.wallet))
             fs.close()
         except Exception as e:
-            self.log.warn("Cannot load algo. Creating a mem file...")
+            self.log.warn("Cannot load algo. Creating a mem file...   "   + str(e))
             self.save_algo()
     
     def run(self):
